@@ -4,10 +4,17 @@ from abc import ABC, abstractmethod
 from typing import Callable, List
 
 import dill
+import dis
+import logging
 
+from deltalanguage.logging import make_logger
+from deltalanguage.data_types import DeltaIOError
 from .latency import Latency
 
 
+log = make_logger(logging.WARNING, "Bodies")
+
+
 class Body(ABC):
 
     def __init__(self,
@@ -50,7 +57,7 @@ class Body(ABC):
 
     @property
     @abstractmethod
-    def as_serialized(self) -> str:
+    def as_serialised(self) -> str:
         """Serialisation of body as string.
 
         Returns
@@ -59,9 +66,60 @@ class Body(ABC):
         """
         pass
 
+    def __eq__(self, other) -> bool:
+        if not isinstance(other, Body):
+            return False
+
+        if self._access_tags != other._access_tags:
+            return False
+
+        if self.latency != other.latency:
+            return False
+
+        return True
+
 
 class PythonBody(Body):
 
+    def python_body_eq(self, other, my_callback):
+
+        # Body class must be the same
+        if type(self) != type(other):
+            print(type(self))
+            print(type(other))
+            return False
+
+        if my_callback.__name__ != other.callback.__name__:
+            return False
+
+        if my_callback.__code__.co_varnames != other.callback.__code__.co_varnames:
+            return False
+
+        if my_callback.__code__.co_consts != other.callback.__code__.co_consts:
+            return False
+
+        my_instructions = list(dis.get_instructions(my_callback))
+        other_instructions = list(dis.get_instructions(other.callback))
+        if len(my_instructions) != len(other_instructions):
+            return False
+
+        for (i, j) in zip(my_instructions, other_instructions):
+            if (i.opcode, i.arg, i.argval) != (j.opcode, j.arg, j.argval):
+                return False
+
+        return True
+
+    @staticmethod
+    def freevar_check(my_callback, other_callback):
+        if my_callback.__code__.co_freevars != other_callback.__code__.co_freevars:
+            return False
+        else:
+            if (my_callback.__code__.co_freevars and
+                    my_callback.__code__.co_freevars != ('self',)):
+                log.warning("Equality called on bodies where functions have free "
+                            f"variables: {my_callback.__code__.co_freevars}")
+        return True
+
     @property
     def language(self) -> str:
         """Language of the body.
@@ -73,7 +131,7 @@ class PythonBody(Body):
         return "Py"
 
     @property
-    def as_serialized(self) -> str:
+    def as_serialised(self) -> str:
         """Serialisation of body as string.
 
         Returns
@@ -104,6 +162,17 @@ class PyFuncBody(PythonBody):
     def eval(self, *args, **kwargs):
         return self.callback(*args, **kwargs)
 
+    def __eq__(self, other) -> bool:
+        """Equality, up to isomorphism as component of .df file.
+        """
+        if not self.python_body_eq(other, self.callback):
+            return False
+
+        if not self.freevar_check(self.callback, other.callback):
+            return False
+
+        return super().__eq__(other)
+
 
 class PyConstBody(PythonBody):
     """Node body for python are to be treated as constant.
@@ -117,6 +186,9 @@ class PyConstBody(PythonBody):
         A callable object that will play a role of the body.
     environment : Callable
         Link to the environment.
+    value
+        For a pure constant node that just represents a single constant value,
+        a single value can be given. The given ``fn`` should return this value.
     args
         Constant arguments for the body.
     kwargs
@@ -124,17 +196,24 @@ class PyConstBody(PythonBody):
     """
 
     def __init__(self, fn, *args,
+                 value=None,
                  latency: Latency = Latency(time=100),
                  tags: List[str] = None, **kwargs):
         tags = tags if tags is not None else []
         super().__init__(latency, tags + [fn.__name__])
-        self.value = None
+        self.constant_value = value
         self.callback = fn
+
+        if self.constant_value is not None:
+            if self.callback() != value:
+                raise DeltaIOError("Callback on pure const node not equal to "
+                                   f"provided value {value}.")
+
         self.args = args
         self.kwargs = kwargs
 
     def eval(self):
-        if self.value is None:
+        if self.constant_value is None:
             # Evaluate value the first time the node is evaluated
             evaluated_args = []
             for arg in self.args:
@@ -168,9 +247,32 @@ class PyConstBody(PythonBody):
                         raise ValueError("Node with a constant body cannot "
                                          "receive \'None\' as input.")
 
-            self.value = self.callback(*evaluated_args, **evaluated_kwargs)
+            self.constant_value = self.callback(
+                *evaluated_args, **evaluated_kwargs)
 
-        return self.value
+        return self.constant_value
+
+    def __eq__(self, other) -> bool:
+        """Equality, up to isomorphism as component of .df file.
+        """
+        if not self.python_body_eq(other, self.callback):
+            return False
+
+        if self.constant_value != other.constant_value:
+            return False
+
+        if (self.constant_value is not None and
+                not self.freevar_check(self.callback, other.callback)):
+            return False
+
+        # args and kwargs are not tested for equality due to recursion.
+        # They are however implictly checked when testing graph
+        # connectivity in graph equality checks.
+        # Here, we just check there are the same number of arguments
+        if len(self.args) + len(self.kwargs) != len(other.args) + len(other.kwargs):
+            return False
+
+        return super().__eq__(other)
 
 
 class PyMethodBody(PythonBody):
@@ -200,6 +302,21 @@ class PyMethodBody(PythonBody):
     def eval(self, *args, **kwargs):
         return self.callback(self.instance, *args, **kwargs)
 
+    def __eq__(self, other) -> bool:
+        """Equality, up to isomorphism as component of .df file.
+        """
+        if not self.python_body_eq(other, self.callback):
+            return False
+
+        if not self.freevar_check(self.callback, other.callback):
+            return False
+
+        # Instances need not be the same, but their type is expected to be
+        if type(self.instance).__name__ != type(other.instance).__name__:
+            return False
+
+        return super().__eq__(other)
+
 
 class PyMigenBody(PyMethodBody):
     """Node body for migen methods.
@@ -239,7 +356,7 @@ class PyMigenBody(PyMethodBody):
                 return ret
 
     @property
-    def as_serialized(self) -> str:
+    def as_serialised(self) -> str:
         """Serialisation of body as string.
 
         Returns
